import React, { useEffect } from "react";
import "./Overlay.css";
import {IOverlayProps } from './Interface.type';

const Overlay: React.FC<IOverlayProps> = ({
  activeElementId,
  onClose,
  colorConfig,
}) => {
  useEffect(() => {
    if (activeElementId) {
      const activeElement = document.getElementById(activeElementId);

      if (activeElement) {
        activeElement.style.position = "relative";
        activeElement.style.zIndex = "9999";
        activeElement.style.boxShadow = `0 0 10px ${colorConfig.highlightColor}`;
      }

      return () => {
        if (activeElement) {
          activeElement.style.position = "";
          activeElement.style.zIndex = "";
          activeElement.style.boxShadow = "";
        }
      };
    }
  }, [activeElementId, colorConfig.highlightColor]);

  return (
    <div
      className="fixed top-0 left-0 w-full h-full"
      style={{
        backgroundColor: colorConfig.overlayBackgroundColor,
        zIndex: 1,
      }}
      onClick={onClose}
    />
  );
};

export default Overlay;
